@@ -15,7 +15,7 @@
 //! assert_eq!(&vec_a * &vec_c, 0);
 //! assert_eq!(&vec_c * &vec_b, 0);
 //!
-//! let mat_a = Matrix::<u32>::one(3);
+//! let mat_a = Matrix::<i32>::one(3);
 //! let mat_b = matrix!{
 //!     1, 2, 3;
 //!     3, 2, 1;
@@ -23,9 +23,14 @@
 //! };
 //!
 //! // Are the matrices invertible?
-//! assert_ne!(mat_a.det(), 0);
-//! assert_ne!(mat_b.det(), 0);
+//! assert_ne!(mat_a.det(), 0_f64);
+//! assert_ne!(mat_b.det(), 0_f64);
 //! ```
+//!
 
+#![doc(html_logo_url = "../logo.png")]
+#![doc(html_no_source)]
+
+// pub mod err;
 mod macros;
 pub mod mat;
